Hi Hannes,

I used git send-email and git format-patch manually, which was a bit of a hassle.

Now I used patman which seems to be really handy, thanks for the hint.


Martin

On 04/27/2016 12:07 PM, Hannes Schmelzer wrote:
Martin,

you have to send also a v2 from "2/2] drivers/video/am335x-fb: Properly point framebuffer behind palette".
v1 doesn't apply after your v2 patch below has been applied.

how do you manage your patch-generation and emailing?

have a look to: tools/patman/README, a really great tool for managing patch-series.

best regards,
Hannes

On 04/27/2016 11:42 AM, Martin Pietryka wrote:
To support 16bpp we just need to change the raster_ctrl register
accordingly. Also 32bpp mode should work as well, but was not tested.
According to the TRM the uppermost byte will be ignored when
LCD_TFT_24BPP_UNPACK is set.

The switch logic is based on the Liunx kernel tilcdc driver:
drivers/gpu/drm/tilcdc/tilcdc_crtc.c: lines 407 through 419
(kernel was checked out at commit: bcc981e9ed8)

Signed-off-by: Martin Pietryka <martin.pietr...@chello.at>
---
  drivers/video/am335x-fb.c | 22 +++++++++++++++++++---
  1 file changed, 19 insertions(+), 3 deletions(-)

diff --git a/drivers/video/am335x-fb.c b/drivers/video/am335x-fb.c
index 0ec843f..569ecb6 100644
--- a/drivers/video/am335x-fb.c
+++ b/drivers/video/am335x-fb.c
@@ -5,7 +5,7 @@
* minimal framebuffer driver for TI's AM335x SoC to be compatible with
   * Wolfgang Denk's LCD-Framework (CONFIG_LCD, common/lcd.c)
   *
  * - supporting only 24bit RGB/TFT raster Mode (not using palette)
   * - sets up LCD controller as in 'am335x_lcdpanel' struct given
   * - starts output DMA from gd->fb_base buffer
   *
@@ -106,6 +106,8 @@ int lcd_get_size(int *line_length)
    int am335xfb_init(struct am335x_lcdpanel *panel)
  {
+    u32 raster_ctrl = 0;
+
      if (0 == gd->fb_base) {
printf("ERROR: no valid fb_base stored in GLOBAL_DATA_PTR!\n");
          return -1;
@@ -115,6 +117,21 @@ int am335xfb_init(struct am335x_lcdpanel *panel)
          return -1;
      }
+ /* We can already set the bits for the raster_ctrl in this check */
+    switch (panel->bpp) {
+    case 16:
+        break;
+    case 32:
+        raster_ctrl |= LCD_TFT_24BPP_UNPACK;
+        /* fallthrough */
+    case 24:
+        raster_ctrl |= LCD_TFT_24BPP_MODE;
+        break;
+    default:
+        error("am335x-fb: invalid bpp value: %d\n", panel->bpp);
+        return -1;
+    }
+
debug("setting up LCD-Controller for %dx%dx%d (hfp=%d,hbp=%d,hsw=%d / ",
            panel->hactive, panel->vactive, panel->bpp,
            panel->hfp, panel->hbp, panel->hsw);
@@ -157,8 +174,7 @@ int am335xfb_init(struct am335x_lcdpanel *panel)
                  LCD_HBPMSB(panel->hbp) |
                  LCD_HFPMSB(panel->hfp) |
                  0x0000FF00;    /* clk cycles for ac-bias */
-    lcdhw->raster_ctrl =    LCD_TFT_24BPP_MODE |
-                LCD_TFT_24BPP_UNPACK |
+ lcdhw->raster_ctrl = raster_ctrl | /* contains the bits for the pixel format */
                  LCD_PALMODE_RAWDATA |
                  LCD_TFT_MODE |
                  LCD_RASTER_ENABLE;
@@ -5,7 +5,7 @@
   * Wolfgang Denk's LCD-Framework (CONFIG_LCD, common/lcd.c)
   *
- * - supporting only 24bit RGB/TFT raster Mode (not using palette)
+ * - supporting 16/24/32bit RGB/TFT raster Mode (not using palette)
   * - sets up LCD controller as in 'am335x_lcdpanel' struct given
   * - starts output DMA from gd->fb_base buffer



_______________________________________________
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot

Reply via email to